==> arquillian-test-spi-1.1.12.Final-sources.jar: org/jboss/arquillian/test/spi/event/enrichment/EnrichmentEvent.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2011 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @authors tag. All rights reserved.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.arquillian.test.spi.event.enrichment;

import java.lang.reflect.Method;

import org.jboss.arquillian.core.spi.event.Event;

/**
 * EnrichmentEvent
 *
 * @author <a href="mailto:aslak@redhat.com">Aslak Knutsen</a>
 * @version $Revision: $
 */
public class EnrichmentEvent implements Event
{
	private Object instance;
    private Method method;

	public EnrichmentEvent(Object instance) {
		this.instance = instance;
	}

    public EnrichmentEvent(Object instance, Method method) {
        this.instance = instance;
        this.method = method;
    }

	public Object getInstance() {
		return instance;
	}

	// Could be null
	public Method getMethod() {
        return method;
    }
}

==> arquillian-test-spi-1.9.3.Final-sources.jar: org/jboss/arquillian/test/spi/event/enrichment/EnrichmentEvent.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2011 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @authors tag. All rights reserved.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.arquillian.test.spi.event.enrichment;

import java.lang.reflect.Method;
import org.jboss.arquillian.core.spi.event.Event;

/**
 * EnrichmentEvent
 *
 * @author <a href="mailto:aslak@redhat.com">Aslak Knutsen</a>
 * @version $Revision: $
 */
public class EnrichmentEvent implements Event {
    private Object instance;
    private Method method;

    public EnrichmentEvent(Object instance) {
        this.instance = instance;
    }

    public EnrichmentEvent(Object instance, Method method) {
        this.instance = instance;
        this.method = method;
    }

    public Object getInstance() {
        return instance;
    }

    // Could be null
    public Method getMethod() {
        return method;
    }
}
